package ca.uol.aig.fts.message;

import au.gov.aao.drama.Arg;
import au.gov.aao.drama.DramaException;
import au.gov.aao.drama.DramaTask;
import au.gov.aao.drama.DramaErs;
import au.gov.aao.drama.DramaStatus;
import au.gov.aao.drama.Sdp;
import au.gov.aao.drama.dul_err;

import ca.uol.aig.fts.drpipeline.DRPipeline;

/**
 * Create a Drama task for the data reduction pipeline
 */
public class Drama2FTS 
{
    DramaTask fts2task = null;

    /**
     * Constructor
     * @param taskName the name of this Drama task
     */
    public Drama2FTS(String taskName)
    {
        try
        {
            initDramaTask(taskName);
        }
        catch(DramaException e)
        {
            e.printStackTrace();
        }
    }
    /* initialize the Drama task */
    void initDramaTask(String taskName) throws DramaException 
    {

        /* Make this JAVA program a DRAMA task named FTS2DRAMA by creating
           a new DramaTask object.
        */
        fts2task = new DramaTask(taskName);

        fts2task.Add("SETPARAMETERS",new SetParametersAction());
        fts2task.Add("DATAREDUCTION",new DataReductionAction());
        fts2task.Add("EXIT",new ExitAction());

        /* enter the DRAMA message receive loop, which will process 
           DRAMA messages received by this task.  All further work is
           done within this call.
        */
        fts2task.RunDrama();
        exitDramaTask();
    }
    /* clean up the Drama task */
    void exitDramaTask()
    {
        /* The message loop has exited (due to task.PutRequestExit() being
           invoked).  Shutdown the DRAMA task down and then set the object
           reference to null
        */
        fts2task.CloseTask(); 
        fts2task = null;
    }
}

/**
 * SetParametersAction is used to create a Drama action dealing with action SETPARAMERTERS. 
 */
class SetParametersAction implements DramaTask.Action 
{
    public void Obey(DramaTask t) throws DramaException  
    {
         Arg arg = t.GetArgument();

         DataReductionParameters.phasecorrection_pcfSize_h = arg.IntValue("pcfSize_h");
         DataReductionParameters.phasecorrection_dsSize = arg.IntValue("dsSize");
         DataReductionParameters.phasecorrection_phaseFittingdegree = arg.IntValue("fittingDegree");
         DataReductionParameters.phasecorrection_weight_limit = arg.RealValue("weight_limit");

         t.PutRequestEnd();
    }
}

/**
 * ExitAction is used to create a Drama action dealing with action EXIT
 */
class ExitAction implements DramaTask.Action
{
    public void Obey(DramaTask t) throws DramaException  
    {
        t.MsgOut("Exit from FTS-2 Pipeline");
        t.PutRequestExit();
    }
}

/**
 * ExitAction is used to create a Drama action dealing with action DATAREDUCTION
 */

class DataReductionAction implements DramaTask.Action 
{
    public void Obey(DramaTask t) throws DramaException 
    {
        Arg arg = t.GetArgument();

        String inPath = arg.StringValue("in");
        String outPath = arg.StringValue("out");

        t.MsgOut(">>> Data Reduction: <IN=" + inPath + ">:<OUT=" + outPath +">");
        new DRPipeline(inPath, outPath,
                       DataReductionParameters.phasecorrection_pcfSize_h,
                       DataReductionParameters.phasecorrection_dsSize,
                       DataReductionParameters.phasecorrection_phaseFittingdegree,
                       DataReductionParameters.phasecorrection_weight_limit); 
        t.MsgOut("End of Data Reduction");
        t.PutRequestEnd();
    }
}

/**
 * DataReductionParameters is used to pass data reduction parameters between different
 * Drama actions.
 */
class DataReductionParameters
{
    /* pathname of I/O files */

    public static String inPath = "";
    public static String outPath = "";

    /* Parameters for Phase Correction */
    public static int phasecorrection_pcfSize_h = 80;
    public static int phasecorrection_dsSize  = 300;
    public static int phasecorrection_phaseFittingdegree = 2;
    public static double phasecorrection_weight_limit = 0.01;
}
